package com.ruoyi.bar.service;

import java.util.List;
import com.ruoyi.bar.domain.WyBar;
import com.ruoyi.common.core.domain.model.BarUserRegisterVO;

/**
 * 酒吧Service接口
 * 
 * @author ruoyi
 * @date 2025-01-02
 */
public interface IWyBarService 
{
    /**
     * 查询酒吧
     * 
     * @param id 酒吧主键
     * @return 酒吧
     */
    public WyBar selectWyBarById(Long id);

    WyBar selectWyBarByNumber(String number);

    WyBar register(BarUserRegisterVO registerVO);

    String getEncryptPassword(String phone);

    /**
     * 查询酒吧列表
     * 
     * @param wyBar 酒吧
     * @return 酒吧集合
     */
    public List<WyBar> selectWyBarList(WyBar wyBar);

    /**
     * 新增酒吧
     * 
     * @param wyBar 酒吧
     * @return 结果
     */
    public int insertWyBar(WyBar wyBar);

    /**
     * 修改酒吧
     * 
     * @param wyBar 酒吧
     * @return 结果
     */
    public int updateWyBar(WyBar wyBar);

    int approvalWyBar(WyBar wyBar);

    /**
     * 批量删除酒吧
     * 
     * @param ids 需要删除的酒吧主键集合
     * @return 结果
     */
    public int deleteWyBarByIds(Long[] ids);

    /**
     * 删除酒吧信息
     * 
     * @param id 酒吧主键
     * @return 结果
     */
    public int deleteWyBarById(Long id);
}
